==> xwidgetsbase-8.7.7.tar.gz: lib/XWidgets/XBTN/XBtnTakePhoto.dart <==
part of xwidgetbase;

class XBtnTakePhoto extends StatelessWidget {
  final Function()? onPressed;
  final String? label;
  final IconData? icon;
  final Color? color;
  final Color? colorbackground;
  final Widget? child;
  TextStyle? style;
  final TextAlign? textAlign;
  final Uint8List? currentImageBytes;
  XBtnTakePhoto({
    this.label,
    this.icon = Icons.add_a_photo,
    this.style,
    this.textAlign,
    this.color,
    this.colorbackground,
    @required this.onPressed,
    this.child,
    this.currentImageBytes,
  });

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        Row(children: <Widget>[Container(alignment: Alignment.center, margin: EdgeInsets.fromLTRB(0, 0, 0, 0), width: 35, height: 13, color: Colors.transparent, child: Text(label ?? "", style: style ??= Theme.of(context).textTheme.caption))]),
        Row(children: <Widget>[
          Container(
            color: colorbackground ?? Colors.transparent,
            margin: EdgeInsets.fromLTRB(0, 0, 0, 0),
            padding: EdgeInsets.fromLTRB(0, 0, 5, 0),
            width: 39,
            height: 40,
            alignment: Alignment.center,
            child: ElevatedButton(
                onPressed: onPressed,
                style: ElevatedButton.styleFrom(
                  primary: Colors.transparent,
                  padding: EdgeInsets.all(2),
                ),
                child: (currentImageBytes == null || currentImageBytes!.isEmpty
                    ? Icon(
                        icon,
                        size: 24,
                        color: color,
                      )
                    : Image.memory(currentImageBytes!))),
          )
        ]),
      ],
    );
  }
}

==> xwidgetsbase-9.3.2.tar.gz: lib/XWidgets/XBTN/XBtnTakePhoto.dart <==
part of xwidgetbase;

class XBtnTakePhoto extends StatelessWidget {
  final Function()? onPressed;
  final String? label;
  final IconData? icon;
  final Color? color;
  final Color? colorbackground;
  final Widget? child;
  TextStyle? style;
  final TextAlign? textAlign;
  final Uint8List? currentImageBytes;
  XBtnTakePhoto({
    this.label,
    this.icon = Icons.add_a_photo,
    this.style,
    this.textAlign,
    this.color,
    this.colorbackground,
    @required this.onPressed,
    this.child,
    this.currentImageBytes,
  });

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        Row(children: <Widget>[Container(alignment: Alignment.center, margin: EdgeInsets.fromLTRB(0, 0, 0, 0), width: 35, height: 13, color: Colors.transparent, child: Text(label ?? "", style: style ??= Theme.of(context).textTheme.caption))]),
        Row(children: <Widget>[
          Container(
            color: colorbackground ?? Colors.transparent,
            margin: EdgeInsets.fromLTRB(0, 0, 0, 0),
            padding: EdgeInsets.fromLTRB(0, 0, 5, 0),
            width: 39,
            height: 40,
            alignment: Alignment.center,
            child: ElevatedButton(
                onPressed: onPressed,
                style: ElevatedButton.styleFrom(
                  backgroundColor: Colors.transparent,
                  padding: EdgeInsets.all(2),
                ),
                child: (currentImageBytes == null || currentImageBytes!.isEmpty
                    ? Icon(
                        icon,
                        size: 24,
                        color: color,
                      )
                    : Image.memory(currentImageBytes!))),
          )
        ]),
      ],
    );
  }
}
